library(ggplot2)

x <- read.csv("pt-bandwidth.csv", colClasses=list(date="Date", default="logical", transport="factor", count="numeric", bandwidth="numeric"))

# Add NAs for missing dates.
all.dates <- expand.grid(date=seq(min(x$date), max(x$date), by="day"), default=c(F, T), transport=c(levels(x$transport)))
x <- merge(x, all.dates, all=T)

# https://gitweb.torproject.org/torspec.git/tree/dir-spec.txt
# "An estimate of the bandwidth of this relay, in an arbitrary unit (currently kilobytes per second)."
p <- ggplot(x, aes(date, bandwidth/1024, color=transport, ymin=0))
p <- p + facet_grid(default ~ ., scales="free_y", labeller=label_both)
p <- p + geom_line()
p <- p + guides(color=guide_legend(override.aes=list(size=5)))
p <- p + labs(y = "Bandwidth (MB/s)", title="Bandwidth by pluggable transport")
ggsave("pt-bandwidth.png", p, width=16, height=7, dpi=90)

p <- ggplot(x, aes(date, count, color=transport, ymin=0))
p <- p + facet_grid(default ~ ., scales="free_y", labeller=label_both)
p <- p + geom_line()
p <- p + guides(color=guide_legend(override.aes=list(size=5)))
p <- p + labs(y = "Bandwidth (MB/s)", title="Number of bridges by pluggable transport")
ggsave("pt-count.png", p, width=16, height=7, dpi=90)
