default.bridges <- read.csv("default-bridges.csv", colClasses="factor")

# These are the two smaller files; load them together, join them, and discard
# the originals.
bridge.server.descriptor <- read.csv("bridge-server-descriptor.csv", colClasses="factor")
bridge.extra.info <- read.csv("bridge-extra-info.csv", colClasses="factor")
bridge.info <- merge(bridge.server.descriptor, bridge.extra.info, by=c("extra.info.digest"), all.x=T)[, c("router.digest", "transport")]
rm(bridge.server.descriptor)
rm(bridge.extra.info)

for (filename in Sys.glob("bridge-network-status-*.csv")) {
	bridge.network.status <- read.csv(filename, colClasses=list(date="factor", hashedfp="factor", bandwidth="integer", router.digest="factor"))
	bridge.network.status$default <- bridge.network.status$hashedfp %in% default.bridges$hashedfp
	x <- merge(bridge.network.status, bridge.info, by=c("router.digest"), all.x=T)[, c("date", "time", "default", "bandwidth", "transport")]
	rm(bridge.network.status)

	# Assign a non-NA value for "no transport", otherwise aggregate will drop it.
	levels(x$transport) <- c(levels(x$transport), "")
	x$transport[is.na(x$transport)] <- ""

	# Total count/bandwidth per consensus.
	x <- aggregate(data.frame(count=1, bandwidth=x$bandwidth), by=list(date=x$date, time=x$time, default=x$default, transport=x$transport), FUN=sum)
	# Mean count/bandwidth per day.
	x <- aggregate(x[c("count", "bandwidth")], by=list(date=x$date, default=x$default, transport=x$transport), FUN=mean)

	write.csv(x, file="", col.names=F, quote=F, row.names=F)
}
