package main

import (
	"archive/tar"
	"io"
)

// tarConcatReader is an io.Reader that concatenates all the files in the
// archive.
type tarConcatReader struct {
	r *tar.Reader
}

func (t *tarConcatReader) Read(p []byte) (int, error) {
	n, err := t.r.Read(p)
	if err == io.EOF {
		_, err = t.r.Next()
	}
	return n, err
}

func newTarConcatReader(r io.Reader) (*tarConcatReader, error) {
	tr := tar.NewReader(r)
	_, err := tr.Next()
	if err != nil {
		return nil, err
	}
	return &tarConcatReader{tr}, nil
}
